==> hestia-earth-models-0.8.4.tar.gz: hestia-earth-models-0.8.4/tests/models/test_otherBackgroundDatabase.py <==
from unittest.mock import patch
import json
from tests.utils import fixtures_path, fake_new_emission

from hestia_earth.models.otherBackgroundDatabase import MODEL, run

class_path = f"hestia_earth.models.{MODEL}"
fixtures_folder = f"{fixtures_path}/{MODEL}"
TERMS = [
    '11DichlorotetrafluoroethaneToAirInputsProduction',
    '112TrichlorotrifluoroethaneToAirInputsProduction',
    '1112TetrafluoroethaneToAirInputsProduction',
    'bromochlorodifluoromethaneToAirInputsProduction',
    'ch4ToAirInputsProductionFossil',
    'ch4ToAirInputsProductionNonFossil',
    'chlorodifluoromethaneToAirInputsProduction',
    'co2ToAirInputsProduction',
    'dichlorodifluoromethaneToAirInputsProduction',
    'n2OToAirInputsProduction',
    'nh3ToAirInputsProduction',
    'noxToAirInputsProduction',
    'so2ToAirInputsProduction'
]


def fake_download_impact(id, *args, **kwargs):
    with open(f"{fixtures_folder}/{id}.jsonld", encoding='utf-8') as f:
        return json.load(f)


@patch(f"{class_path}.get_emission_inputs_production_terms", return_value=TERMS)
@patch(f"{class_path}._emission", return_value={})
def test_run_all_models(mock_emission, *args):
    run(None, {})
    assert mock_emission.call_count == len(TERMS)

    mock_emission.reset_mock()
    run('', {})
    assert mock_emission.call_count == len(TERMS)

    mock_emission.reset_mock()
    run('null', {})
    assert mock_emission.call_count == len(TERMS)

    mock_emission.reset_mock()
    run('all', {})
    assert mock_emission.call_count == len(TERMS)


@patch(F"{class_path}.download_hestia", side_effect=fake_download_impact)
@patch(f"{class_path}.get_emission_inputs_production_terms", return_value=TERMS)
@patch(f"{class_path}._new_emission", side_effect=fake_new_emission)
def test_run(*args):
    with open(f"{fixtures_folder}/cycle.jsonld", encoding='utf-8') as f:
        cycle = json.load(f)

    with open(f"{fixtures_folder}/result.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    value = run('all', cycle)
    assert value == expected

==> hestia-earth-models-0.14.3.tar.gz: hestia-earth-models-0.14.3/tests/models/test_otherBackgroundDatabase.py <==
from unittest.mock import patch
import json
from hestia_earth.utils.tools import non_empty_list
from tests.utils import fixtures_path, fake_new_emission

from hestia_earth.models.otherBackgroundDatabase import MODEL, run

class_path = f"hestia_earth.models.{MODEL}"
fixtures_folder = f"{fixtures_path}/{MODEL}"
TERMS = [
    '11DichlorotetrafluoroethaneToAirInputsProduction',
    '112TrichlorotrifluoroethaneToAirInputsProduction',
    '1112TetrafluoroethaneToAirInputsProduction',
    'bromochlorodifluoromethaneToAirInputsProduction',
    'ch4ToAirInputsProductionFossil',
    'ch4ToAirInputsProductionNonFossil',
    'chlorodifluoromethaneToAirInputsProduction',
    'co2ToAirInputsProduction',
    'dichlorodifluoromethaneToAirInputsProduction',
    'n2OToAirInputsProduction',
    'nh3ToAirInputsProduction',
    'noxToAirInputsProduction',
    'so2ToAirInputsProduction'
]


def fake_load_impacts(inputs):
    def _load_impact(input: dict):
        impact = input.get('impactAssessment')
        if impact:
            with open(f"{fixtures_path}/impact_assessment/{impact.get('@id')}.jsonld", encoding='utf-8') as f:
                return {**input, 'impactAssessment': json.load(f)}
    return non_empty_list(map(_load_impact, inputs))


@patch(f"{class_path}.get_emission_inputs_production_terms", return_value=TERMS)
@patch(f"{class_path}._emission", return_value={})
def test_run_all_models(mock_emission, *args):
    run(None, {})
    assert mock_emission.call_count == len(TERMS)

    mock_emission.reset_mock()
    run('', {})
    assert mock_emission.call_count == len(TERMS)

    mock_emission.reset_mock()
    run('null', {})
    assert mock_emission.call_count == len(TERMS)

    mock_emission.reset_mock()
    run('all', {})
    assert mock_emission.call_count == len(TERMS)


@patch(F"{class_path}.load_impacts", side_effect=fake_load_impacts)
@patch(f"{class_path}.get_emission_inputs_production_terms", return_value=TERMS)
@patch(f"{class_path}._new_emission", side_effect=fake_new_emission)
def test_run(*args):
    with open(f"{fixtures_folder}/cycle.jsonld", encoding='utf-8') as f:
        cycle = json.load(f)

    with open(f"{fixtures_folder}/result.jsonld", encoding='utf-8') as f:
        expected = json.load(f)

    value = run('all', cycle)
    assert value == expected
